@@ -2,9 +2,10 @@ import copy
 import os
 import typing
 from typing import Any, Iterable
+
 from policyengine_core import commons, parameters, tools
 from policyengine_core.errors import ParameterParsingError
-from policyengine_core.parameters import config, helpers, AtInstantLike
+from policyengine_core.parameters import AtInstantLike, config, helpers
 from policyengine_core.periods.instant_ import Instant
 from policyengine_core.taxscales import (
     LinearAverageRateTaxScale,
@@ -71,7 +72,8 @@ class ParameterScale(AtInstantLike):
         )
 
     def get_descendants(self) -> Iterable:
-        return iter(())
+        for bracket in self.brackets:
+            yield from bracket.get_descendants()
 
     def clone(self) -> "ParameterScale":
         clone = commons.empty_clone(self)
