@@ -18,13 +18,19 @@ class SimpleTracer:
     def __init__(self) -> None:
         self._stack = []
 
-    def record_calculation_start(self, variable: str, period: Period) -> None:
-        self.stack.append({"name": variable, "period": period})
+    def record_calculation_start(
+        self, variable: str, period: Period, branch_name: str = "default"
+    ) -> None:
+        self.stack.append(
+            {"name": variable, "period": period, "branch_name": branch_name}
+        )
 
     def record_calculation_result(self, value: ArrayLike) -> None:
         pass  # ignore calculation result
 
-    def record_parameter_access(self, parameter: str, period, value):
+    def record_parameter_access(
+        self, parameter: str, period, branch_name: str, value
+    ):
         pass
 
     def record_calculation_end(self) -> None:
